/*******************************************************************************
***  This file is part of Qt Mocks.                                          ***
***                                                                          ***
***  Copyright (C) 2018, 2019, 2020, 2021                                    ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Lesser General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Lesser General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Lesser General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef QT_MOCKS_MOCK_HPP
#define QT_MOCKS_MOCK_HPP

#include <QTest>

#include <exception>
#include <functional>
#include <sstream>
#include <vector>

#include "Matchers.h"
#include "Verify.hpp"


/**
 * @brief Generates an empty member accessor.
 *
 * @param returnValue This is the type the member accessor returns.
 * @param functionName This is the name of the member accessor.
 */
#define QMOCK_MEMBER_ACCESSOR(returnValue, functionName)  \
	returnValue functionName() override  \
	{  \
		return {};  \
	}
/**
 * @brief Generates an empty member function.
 *
 * @param functionName This is the name of the member function.
 * @param ... Any number of arguments expected by the member function.
 */
#define QMOCK_MEMBER_FUNCTION_VOID(functionName, ...)  \
	void functionName(__VA_ARGS__) override  \
	{}
/**
 * @brief Generates an empty member function.
 *
 * @param functionName This is the name of the member function.
 * @param ... Any number of arguments expected by the member function.
 */
#define QMOCK_MEMBER_FUNCTION_VOID_NOARGS(functionName)  \
	void functionName() override  \
	{}
/**
 * @brief Generates an empty member function.
 *
 * @param returnValue This is the type the member function returns.
 * @param functionName This is the name of the member function.
 * @param ... Any number of arguments expected by the member function.
 */
#define QMOCK_MEMBER_FUNCTION(returnValue, functionName, ...)  \
	returnValue functionName(__VA_ARGS__) override  \
	{  \
		return {};  \
	}

#endif
